// CampaignDetail.js
import React, { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import ProgressBar from './ProgressBar';
import './App.css';

function CampaignDetail() {
  const { id } = useParams();
  const [campaign, setCampaign] = useState(null);
  const [donations, setDonations] = useState([]);

  useEffect(() => {
    fetch(`http://localhost:4000/api/campaigns/${id}`)
      .then((res) => res.json())
      .then((data) => setCampaign(data))
      .catch((err) => console.error(err));

    fetch(`http://localhost:4000/api/campaigns/${id}/donations`)
      .then((res) => res.json())
      .then((data) => setDonations(data))
      .catch((err) => console.error(err));
  }, [id]);

  if (!campaign) return <div>Ładowanie...</div>;

  return (
    <div className="container">
      <div className="card">
        <h1>{campaign.title}</h1>
        <p>{campaign.description}</p>
        <ProgressBar value={campaign.totalDonations} max={campaign.target} />
        <p style={{ textAlign: 'center' }}>
          <strong>{campaign.totalDonations} zł</strong> z <strong>{campaign.target} zł</strong>
        </p>
        <h2>Ostatnie wpłaty</h2>
        <ul>
          {donations.map((d) => (
            <li key={d.id}>
              Kwota: {d.amount} zł – {d.description} – {new Date(d.date).toLocaleString()}
            </li>
          ))}
        </ul>
      </div>
    </div>
  );
}

export default CampaignDetail;
